==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/ro/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "trim. acesta",
	"field-quarter-short-relative+1": "trim. viitor",
	"field-tue-relative+-1": "marțea trecută",
	"field-year": "an",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "miercurea aceasta",
	"field-wed-relative+1": "miercurea viitoare",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minut",
	"field-tue-narrow-relative+0": "ma. aceasta",
	"field-tue-narrow-relative+1": "ma. viitoare",
	"field-thu-short-relative+0": "joi aceasta",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "joia viitoare",
	"field-day-relative+0": "azi",
	"field-day-relative+1": "mâine",
	"field-day-relative+2": "poimâine",
	"field-wed-narrow-relative+-1": "mi. trecută",
	"field-year-narrow": "an",
	"field-tue-relative+0": "marțea aceasta",
	"field-tue-relative+1": "marțea viitoare",
	"field-second-short": "sec.",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "săptămâna aceasta",
	"field-month-relative+0": "luna aceasta",
	"field-week-relative+1": "săptămâna viitoare",
	"field-month-relative+1": "luna viitoare",
	"field-sun-narrow-relative+0": "du. aceasta",
	"field-mon-short-relative+0": "lun. aceasta",
	"field-sun-narrow-relative+1": "du. viitoare",
	"field-mon-short-relative+1": "lun. viitoare",
	"field-second-relative+0": "acum",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-month-short": "lună",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "dd.MM.y G",
	"field-day": "zi",
	"field-year-relative+-1": "anul trecut",
	"field-sat-short-relative+-1": "sâm. trecută",
	"field-hour-relative+0": "ora aceasta",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y G",
	"field-wed-relative+-1": "miercurea trecută",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "sâ. trecută",
	"field-second": "secundă",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "trimestru",
	"field-week-short": "săpt.",
	"field-tue-short-relative+0": "mar. aceasta",
	"field-tue-short-relative+1": "mar. viitoare",
	"field-mon-relative+-1": "lunea trecută",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "lună",
	"field-day-narrow": "zi",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "a.m/p.m.",
	"field-sat-short-relative+0": "sâm. aceasta",
	"field-sat-short-relative+1": "sâm. viitoare",
	"dateFormat-medium": "dd.MM.y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "MM.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "lunea aceasta",
	"field-mon-relative+1": "lunea viitoare",
	"field-year-short": "an",
	"field-quarter-relative+-1": "trimestrul trecut",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-sat-relative+-1": "sâmbăta trecută",
	"dateTimeFormat-long": "{1} 'la' {0}",
	"dateFormatItem-Md": "dd.MM",
	"field-hour": "oră",
	"dateFormat-full": "EEEE, d MMMM y G",
	"field-month-relative+-1": "luna trecută",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "sâ. aceasta",
	"field-fri-relative+0": "vinerea aceasta",
	"field-sat-narrow-relative+1": "sâ. viitoare",
	"field-fri-relative+1": "vinerea viitoare",
	"field-sun-short-relative+0": "dum. aceasta",
	"field-sun-short-relative+1": "dum. viitoare",
	"field-week-relative+-1": "săptămâna trecută",
	"field-quarter-short-relative+-1": "trim. trecut",
	"field-quarter-relative+0": "trimestrul acesta",
	"field-minute-relative+0": "minutul acesta",
	"field-quarter-relative+1": "trimestrul viitor",
	"field-wed-short-relative+-1": "mie. trecută",
	"dateFormat-short": "dd.MM.y GGGGG",
	"field-thu-short-relative+-1": "joi trecută",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "lu. trecută",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "jo. trecută",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "ma. trecută",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "mie. aceasta",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "mie. viitoare",
	"field-sun-relative+-1": "duminica trecută",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateTimeFormat-full": "{1} 'la' {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "Zi a săptămânii",
	"field-quarter-narrow-relative+0": "trim. acesta",
	"field-sat-relative+0": "sâmbăta aceasta",
	"field-quarter-narrow-relative+1": "trim. viitor",
	"field-sat-relative+1": "sâmbăta viitoare",
	"dateFormatItem-MEd": "E, dd.MM",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "jo. aceasta",
	"field-thu-narrow-relative+1": "jo. viitoare",
	"field-sun-narrow-relative+-1": "du. trecută",
	"field-mon-short-relative+-1": "lun. trecută",
	"field-thu-relative+0": "joia aceasta",
	"field-thu-relative+1": "joia viitoare",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "vin. trecută",
	"field-thu-relative+-1": "joia trecută",
	"field-week": "săptămână",
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "mi. aceasta",
	"field-wed-narrow-relative+1": "mi. viitoare",
	"field-quarter-narrow-relative+-1": "trim. trecut",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-fri-short-relative+0": "vin. aceasta",
	"field-fri-short-relative+1": "vin. viitoare",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "h",
	"field-month-narrow": "lună",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "vi. trecută",
	"field-year-relative+0": "anul acesta",
	"field-year-relative+1": "anul viitor",
	"field-fri-relative+-1": "vinerea trecută",
	"field-tue-short-relative+-1": "mar. trecută",
	"field-minute-narrow": "m",
	"field-mon-narrow-relative+0": "lu. aceasta",
	"field-mon-narrow-relative+1": "lu. viitoare",
	"field-zone": "fus orar",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "dum. trecută",
	"field-day-relative+-1": "ieri",
	"field-day-relative+-2": "alaltăieri",
	"field-sun-relative+0": "duminica aceasta",
	"field-sun-relative+1": "duminica viitoare",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "zi",
	"field-week-narrow": "săpt.",
	"field-era": "eră",
	"field-fri-narrow-relative+0": "vi. aceasta",
	"field-fri-narrow-relative+1": "vi. viitoare"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/ro/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "trim. acesta",
	"field-quarter-short-relative+1": "trim. viitor",
	"field-tue-relative+-1": "marțea trecută",
	"field-year": "an",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "miercurea aceasta",
	"field-wed-relative+1": "miercurea viitoare",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minut",
	"field-month-narrow-relative+-1": "luna trecută",
	"field-tue-narrow-relative+0": "ma. aceasta",
	"field-tue-narrow-relative+1": "ma. viitoare",
	"field-day-short-relative+-1": "ieri",
	"field-thu-short-relative+0": "joia aceasta",
	"dateTimeFormat-short": "{1}, {0}",
	"field-day-relative+0": "azi",
	"field-day-short-relative+-2": "alaltăieri",
	"field-thu-short-relative+1": "joia viitoare",
	"field-day-relative+1": "mâine",
	"field-week-narrow-relative+0": "săpt. aceasta",
	"field-day-relative+2": "poimâine",
	"field-week-narrow-relative+1": "săpt. viitoare",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-wed-narrow-relative+-1": "mi. trecută",
	"field-year-narrow": "an",
	"field-era-short": "eră",
	"field-year-narrow-relative+0": "anul acesta",
	"field-tue-relative+0": "marțea aceasta",
	"field-year-narrow-relative+1": "anul viitor",
	"field-tue-relative+1": "marțea viitoare",
	"field-weekdayOfMonth": "ziua săptămânii din lună",
	"field-second-short": "sec.",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "ziua săpt. din lună",
	"field-week-relative+0": "săptămâna aceasta",
	"field-month-relative+0": "luna aceasta",
	"field-week-relative+1": "săptămâna viitoare",
	"field-month-relative+1": "luna viitoare",
	"field-sun-narrow-relative+0": "du. aceasta",
	"field-mon-short-relative+0": "lun. aceasta",
	"field-sun-narrow-relative+1": "du. viitoare",
	"field-mon-short-relative+1": "lun. viitoare",
	"field-second-relative+0": "acum",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "săptămâna din lună",
	"field-month-short": "lună",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "dd.MM.y G",
	"field-day": "zi",
	"field-dayOfYear-short": "ziua din an",
	"field-year-relative+-1": "anul trecut",
	"field-sat-short-relative+-1": "sâm. trecută",
	"field-hour-relative+0": "ora aceasta",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y G",
	"field-second-short-relative+0": "acum",
	"field-wed-relative+-1": "miercurea trecută",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "sâ. trecută",
	"field-second": "secundă",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-hour-short-relative+0": "ora aceasta",
	"field-quarter": "trimestru",
	"field-week-short": "săpt.",
	"field-day-narrow-relative+0": "azi",
	"field-day-narrow-relative+1": "mâine",
	"field-day-narrow-relative+2": "poimâine",
	"field-tue-short-relative+0": "mar. aceasta",
	"field-tue-short-relative+1": "mar. viitoare",
	"field-month-short-relative+-1": "luna trecută",
	"field-mon-relative+-1": "lunea trecută",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "lună",
	"field-day-narrow": "zi",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "a.m/p.m.",
	"field-sat-short-relative+0": "sâm. aceasta",
	"field-sat-short-relative+1": "sâm. viitoare",
	"dateFormat-medium": "dd.MM.y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "MM.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "lunea aceasta",
	"field-mon-relative+1": "lunea viitoare",
	"field-day-narrow-relative+-1": "ieri",
	"field-year-short": "an",
	"field-day-narrow-relative+-2": "alaltăieri",
	"field-quarter-relative+-1": "trimestrul trecut",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "a.m/p.m.",
	"field-week-narrow-relative+-1": "săpt. trecută",
	"field-dayOfYear": "ziua din an",
	"field-sat-relative+-1": "sâmbăta trecută",
	"dateTimeFormat-long": "{1} 'la' {0}",
	"dateFormatItem-Md": "dd.MM",
	"field-hour": "oră",
	"field-minute-narrow-relative+0": "minutul acesta",
	"dateFormat-full": "EEEE, d MMMM y G",
	"field-month-relative+-1": "luna trecută",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "sâ. aceasta",
	"field-fri-relative+0": "vinerea aceasta",
	"field-sat-narrow-relative+1": "sâ. viitoare",
	"field-fri-relative+1": "vinerea viitoare",
	"dateFormatItem-EBhm": "E h:mm B",
	"field-month-narrow-relative+0": "luna aceasta",
	"field-month-narrow-relative+1": "luna viitoare",
	"field-sun-short-relative+0": "dum. aceasta",
	"field-sun-short-relative+1": "dum. viitoare",
	"field-week-relative+-1": "săptămâna trecută",
	"field-quarter-short-relative+-1": "trim. trecut",
	"dateFormatItem-Ehm": "E h:mm a",
	"field-minute-short-relative+0": "minutul acesta",
	"field-quarter-relative+0": "trimestrul acesta",
	"field-minute-relative+0": "minutul acesta",
	"field-quarter-relative+1": "trimestrul viitor",
	"field-wed-short-relative+-1": "mie. trecută",
	"dateFormat-short": "dd.MM.y GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-year-narrow-relative+-1": "anul trecut",
	"field-thu-short-relative+-1": "joia trecută",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "lu. trecută",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "jo. trecută",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "săpt. din lună",
	"field-tue-narrow-relative+-1": "ma. trecută",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "mie. aceasta",
	"field-wed-short-relative+1": "mie. viitoare",
	"field-sun-relative+-1": "duminica trecută",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateTimeFormat-full": "{1} 'la' {0}",
	"field-second-narrow-relative+0": "acum",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "ziua din săptămână",
	"field-day-short-relative+0": "azi",
	"field-quarter-narrow-relative+0": "trim. acesta",
	"field-day-short-relative+1": "mâine",
	"field-sat-relative+0": "sâmbăta aceasta",
	"field-quarter-narrow-relative+1": "trim. viitor",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "poimâine",
	"field-sat-relative+1": "sâmbăta viitoare",
	"field-week-short-relative+0": "săpt. aceasta",
	"field-week-short-relative+1": "săpt. viitoare",
	"field-dayOfYear-narrow": "ziua din an",
	"field-month-short-relative+0": "luna aceasta",
	"field-month-short-relative+1": "luna viitoare",
	"field-weekdayOfMonth-short": "ziua săpt. din lună",
	"dateFormatItem-MEd": "E, dd.MM",
	"field-zone-narrow": "fus",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "jo. aceasta",
	"field-sun-narrow-relative+-1": "du. trecută",
	"field-mon-short-relative+-1": "lun. trecută",
	"field-thu-narrow-relative+1": "jo. viitoare",
	"field-thu-relative+0": "joia aceasta",
	"field-thu-relative+1": "joia viitoare",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "vin. trecută",
	"field-thu-relative+-1": "joia trecută",
	"field-week": "săptămână",
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "mi. aceasta",
	"field-wed-narrow-relative+1": "mi. viitoare",
	"field-quarter-narrow-relative+-1": "trim. trecut",
	"field-year-short-relative+0": "anul acesta",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "a.m/p.m.",
	"field-year-short-relative+1": "anul viitor",
	"field-fri-short-relative+0": "vin. aceasta",
	"field-fri-short-relative+1": "vin. viitoare",
	"field-week-short-relative+-1": "săpt. trecută",
	"field-hour-narrow-relative+0": "ora aceasta",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "h",
	"field-zone-short": "fus",
	"field-month-narrow": "lună",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "vi. trecută",
	"field-year-relative+0": "anul acesta",
	"field-year-relative+1": "anul viitor",
	"field-era-narrow": "eră",
	"field-fri-relative+-1": "vinerea trecută",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-tue-short-relative+-1": "mar. trecută",
	"field-minute-narrow": "m",
	"field-mon-narrow-relative+0": "lu. aceasta",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "lu. viitoare",
	"field-year-short-relative+-1": "anul trecut",
	"field-zone": "fus orar",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-weekOfMonth-narrow": "săpt. din lună",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-weekday-narrow": "ziua din săpt.",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "dum. trecută",
	"field-day-relative+-1": "ieri",
	"field-day-relative+-2": "alaltăieri",
	"field-weekday-short": "ziua din săpt.",
	"dateFormatItem-Bhm": "h:mm B",
	"field-sun-relative+0": "duminica aceasta",
	"field-sun-relative+1": "duminica viitoare",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "zi",
	"field-week-narrow": "săpt.",
	"field-era": "eră",
	"field-fri-narrow-relative+0": "vi. aceasta",
	"field-fri-narrow-relative+1": "vi. viitoare"
}
//end v1.x content
);
